@@ -47,7 +47,7 @@
 #include "raftlist.h"
 #include "reinforcement-point-list.h"
 #include "soundset.h"
-#include "sound.h"
+#include "snd.h"
 
 std::string GameScenario::d_tag = "scenario";
 std::string GameScenario::d_top_tag = "game";
@@ -135,7 +135,7 @@ bool GameScenario::loadSoundset (Tar_Helper *t)
         }
       soundset->setPieces(new_pieces);
       if (!broken)
-        Sound::getInstance()->loadSoundset(soundset);
+        Snd::getInstance()->loadSoundset(soundset);
     }
   return broken;
 }
@@ -273,7 +273,7 @@ GameScenario::saveGame (string filename, string extension) const
   File::erase(map_image_file);
   File::erase(wall_image_file);
 
-  Soundset *soundset = Sound::getInstance()->getSoundset();
+  Soundset *soundset = Snd::getInstance()->getSoundset();
   XML_Helper soundhelper (tmpfile + "-music.xml", ios::out, false);
   retval &= soundset->save(&soundhelper);
   soundhelper.close ();
