@@ -40,7 +40,6 @@
 
 #include "ucompose.hpp"
 #include "defs.h"
-#include "sound.h"
 #include "File.h"
 #include "game.h"
 #include "GameScenarioOptions.h"
@@ -62,6 +61,7 @@
 
 #include "preferences-dialog.h"
 #include "dicebox.h"
+#include "snd.h"
 
 GameWindow::GameWindow()
 {
@@ -256,10 +256,10 @@ bool GameWindow::on_map_mouse_button_event(GdkEventButton *event)
                   get_active_dicebox()->clear_selected_die();
                 }
               else
-                ;//Sound::getInstance()->playMusic("blocked");
+                Snd::getInstance()->play("blocked");
             }
           else
-            Sound::getInstance()->playMusic("blocked");
+            Snd::getInstance()->play("blocked");
         }
       else if (mode == DiceBox::ATTACK && 
                p->getActivestack() && is_inside(selected_attack_box,tile) &&
@@ -291,19 +291,13 @@ bool GameWindow::on_map_mouse_button_event(GdkEventButton *event)
                                 String::ucompose("Must be next to the %1 to attack it.",
                                                  enemy->front()->getName());
                               statusbar->push(s);
-                              Sound::getInstance()->playMusic("blocked");
+                              Snd::getInstance()->play("blocked");
                             }
                           else
                             {
                               Fight::Result result = p->stackFight(&stack, &enemy,
                                                                    selected_die_value);
                               p->setActivestack(NULL);
-                              //if (result == Fight::ATTACKER_WON) 
-                                //Sound::getInstance()->playMusic("victory");
-                              //else if (result == Fight::DEFENDER_WON)
-                                //Sound::getInstance()->playMusic("defeat");
-                              //else if (result == Fight::DRAW)
-                                //Sound::getInstance()->playMusic("draw");
                               redraw();
                               get_active_dicebox()->clear_selected_die();
                               if ((enemy_is_general && 
@@ -316,20 +310,20 @@ bool GameWindow::on_map_mouse_button_event(GdkEventButton *event)
                       else
                         {
                           statusbar->push("Cannot attack across water!");
-                          Sound::getInstance()->playMusic("blocked");
+                          Snd::getInstance()->play("blocked");
                         }
 
                     }
                   else
                     {
                       statusbar->push("Cannot attack over/past other enemy units!");
-                      Sound::getInstance()->playMusic("blocked");
+                      Snd::getInstance()->play("blocked");
                     }
                 }
               else
                 {
                   statusbar->push("Cannot attack over a brick wall!");
-                  Sound::getInstance()->playMusic("blocked");
+                  Snd::getInstance()->play("blocked");
                 }
             }
           else if (GameMap::getInstance()->getTile(tile)->getType() == Maptile::BRICK && p->getActivestack() && selected_die_value == p->getActivestack()->getMinimumDieToBreakBrick() && p->getActivestack()->canDestroyBrick())
@@ -337,7 +331,7 @@ bool GameWindow::on_map_mouse_button_event(GdkEventButton *event)
               GameMap::getInstance()->getTile(tile)->setType(Maptile::BROKEN_BRICK);
               p->setActivestack(NULL);
               redraw();
-              Sound::getInstance()->playMusic("victory");
+              Snd::getInstance()->play("victory");
               while (g_main_context_iteration(NULL, FALSE)); //doEvents
               Glib::usleep(3000000);
               get_active_dicebox()->clear_selected_die();
@@ -477,7 +471,7 @@ void GameWindow::setup_signals(GameScenario *game_scenario)
      
 void GameWindow::on_raft_moves(Stack *s, std::list<Vector<int> > points)
 {
-  Sound::getInstance()->playMusic("raft");
+  Snd::getInstance()->play("raft");
   raft_is_currently_moving = GameMap::getRaft(s->getPos());
   stack_is_currently_moving = s;
   for (std::list<Vector<int> >::iterator i = ++points.begin(); i != points.end();
@@ -505,14 +499,14 @@ void GameWindow::on_stack_moves(Stack *s, std::list<Vector<int> > points, Vector
         {
           statusbar->push("Blocked!");
           s->setPos(points.front());
-          Sound::getInstance()->playMusic("blocked");
+          Snd::getInstance()->play("blocked");
           break;
         }
       if ((*i) == stopped_short)
         {
           statusbar->push("The water slows your army unit down!");
           s->setPos(points.front());
-          Sound::getInstance()->playMusic("stopped-short");
+          Snd::getInstance()->play("stopped-short");
           break;
         }
       while (g_main_context_iteration(NULL, FALSE)); //doEvents
@@ -536,15 +530,15 @@ void GameWindow::on_fight_started(Fight::Result result, int defender_roll,
     {
     case Fight::DRAW:
       statusbar->push(s + ".  Your army fights to a draw.");
-      Sound::getInstance()->playMusic("draw");
+      Snd::getInstance()->play("draw");
       break;
     case Fight::ATTACKER_WON:
       statusbar->push(s + ".  Your army is victorious!");
-      Sound::getInstance()->playMusic("victory");
+      Snd::getInstance()->play("victory");
       break;
     case Fight::DEFENDER_WON:
       statusbar->push(s + ".  Your army is defeated!");
-      Sound::getInstance()->playMusic("defeat");
+      Snd::getInstance()->play("defeat");
       break;
     }
   while (g_main_context_iteration(NULL, FALSE)); //doEvents
@@ -693,8 +687,6 @@ bool GameWindow::setup_game(GameScenario *game_scenario, NextTurn *nextTurn)
 {
   save_game_menuitem->set_sensitive(true);
   save_as_game_menuitem->set_sensitive(true);
-  Sound::getInstance()->haltMusic(false);
-  Sound::getInstance()->enableBackground();
 
   if (game)
     delete game;
@@ -917,7 +909,6 @@ void GameWindow::on_help_about_activated()
 void GameWindow::stop_game(std::string action)
 {
   stop_action = action;
-  Sound::getInstance()->disableBackground();
   if (game)
     {
       current_save_filename = "";
